@@ -3,3 +3,7 @@ BASE_PACKAGE_NAME = 'sedaro_base_client'
 CREATE = 'create'
 UPDATE = 'update'
 DELETE = 'delete'
+
+COMMON_API_KWARGS = {
+    'skip_deserialization': True
+}
