@@ -30,6 +30,28 @@ from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_ground_t
 from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_ground_targets_block_id import ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_target_groups_ import ModelsBranchesBranchIdCdhConopsTargetGroups
 from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_conops_target_groups_block_id import ModelsBranchesBranchIdCdhConopsTargetGroupsBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_types_ import ModelsBranchesBranchIdCdhDataDataTypes
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_types_block_id import ModelsBranchesBranchIdCdhDataDataTypesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_internal_data_interfaces_ import ModelsBranchesBranchIdCdhDataInternalDataInterfaces
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_internal_data_interfaces_block_id import ModelsBranchesBranchIdCdhDataInternalDataInterfacesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_passive_transmit_interfaces_ import ModelsBranchesBranchIdCdhDataPassiveTransmitInterfaces
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_passive_transmit_interfaces_block_id import ModelsBranchesBranchIdCdhDataPassiveTransmitInterfacesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_cooperative_transmit_interfaces_ import ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfaces
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_cooperative_transmit_interfaces_block_id import ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfacesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_receive_interfaces_ import ModelsBranchesBranchIdCdhDataReceiveInterfaces
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_receive_interfaces_block_id import ModelsBranchesBranchIdCdhDataReceiveInterfacesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_busses_ import ModelsBranchesBranchIdCdhDataDataBusses
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_busses_block_id import ModelsBranchesBranchIdCdhDataDataBussesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_storage_ import ModelsBranchesBranchIdCdhDataDataStorage
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_storage_block_id import ModelsBranchesBranchIdCdhDataDataStorageBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_modes_ import ModelsBranchesBranchIdCdhDataDataModes
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_data_modes_block_id import ModelsBranchesBranchIdCdhDataDataModesBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_modem_ import ModelsBranchesBranchIdCdhDataModem
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_modem_block_id import ModelsBranchesBranchIdCdhDataModemBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_antenna_ import ModelsBranchesBranchIdCdhDataAntenna
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_antenna_block_id import ModelsBranchesBranchIdCdhDataAntennaBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_laser_comm_module_ import ModelsBranchesBranchIdCdhDataLaserCommModule
+from sedaro_base_client.apis.paths.models_branches_branch_id_cdh_data_laser_comm_module_block_id import ModelsBranchesBranchIdCdhDataLaserCommModuleBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_ import ModelsBranchesBranchIdPowerSolarArrays
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_block_id import ModelsBranchesBranchIdPowerSolarArraysBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_solar_arrays_panels_ import ModelsBranchesBranchIdPowerSolarArraysPanels
@@ -41,7 +63,7 @@ from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_pac
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_packs_block_id import ModelsBranchesBranchIdPowerBatteriesPacksBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_cells_ import ModelsBranchesBranchIdPowerBatteriesCells
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_batteries_cells_block_id import ModelsBranchesBranchIdPowerBatteriesCellsBlockId
-from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_topology_block_id import ModelsBranchesBranchIdPowerEpsTopologyBlockId
+from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_power_processor_block_id import ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_bus_regulators_ import ModelsBranchesBranchIdPowerEpsBusRegulators
 from sedaro_base_client.apis.paths.models_branches_branch_id_power_eps_bus_regulators_block_id import ModelsBranchesBranchIdPowerEpsBusRegulatorsBlockId
 from sedaro_base_client.apis.paths.models_branches_branch_id_thermal_temp_controllers_heaters_ import ModelsBranchesBranchIdThermalTempControllersHeaters
@@ -160,6 +182,28 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_: ModelsBranchesBranchIdCdhConopsTargetGroups,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsTargetGroupsBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_: ModelsBranchesBranchIdCdhDataDataTypes,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataTypesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_: ModelsBranchesBranchIdCdhDataInternalDataInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataInternalDataInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_: ModelsBranchesBranchIdCdhDataReceiveInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataReceiveInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_: ModelsBranchesBranchIdCdhDataDataBusses,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataBussesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_: ModelsBranchesBranchIdCdhDataDataStorage,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataStorageBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_: ModelsBranchesBranchIdCdhDataDataModes,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataModesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_: ModelsBranchesBranchIdCdhDataModem,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_BLOCK_ID: ModelsBranchesBranchIdCdhDataModemBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_: ModelsBranchesBranchIdCdhDataAntenna,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_BLOCK_ID: ModelsBranchesBranchIdCdhDataAntennaBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_: ModelsBranchesBranchIdCdhDataLaserCommModule,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_BLOCK_ID: ModelsBranchesBranchIdCdhDataLaserCommModuleBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_: ModelsBranchesBranchIdPowerSolarArrays,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_: ModelsBranchesBranchIdPowerSolarArraysPanels,
@@ -171,7 +215,7 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesPacksBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_: ModelsBranchesBranchIdPowerBatteriesCells,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesCellsBlockId,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_TOPOLOGY_BLOCK_ID: ModelsBranchesBranchIdPowerEpsTopologyBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_POWERPROCESSOR_BLOCK_ID: ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_: ModelsBranchesBranchIdPowerEpsBusRegulators,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_BLOCK_ID: ModelsBranchesBranchIdPowerEpsBusRegulatorsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_: ModelsBranchesBranchIdThermalTempControllersHeaters,
@@ -291,6 +335,28 @@ path_to_api = PathToApi(
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsGroundTargetsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_: ModelsBranchesBranchIdCdhConopsTargetGroups,
         PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_BLOCK_ID: ModelsBranchesBranchIdCdhConopsTargetGroupsBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_: ModelsBranchesBranchIdCdhDataDataTypes,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataTypesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_: ModelsBranchesBranchIdCdhDataInternalDataInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataInternalDataInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataPassiveTransmitInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataCooperativeTransmitInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_: ModelsBranchesBranchIdCdhDataReceiveInterfaces,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_BLOCK_ID: ModelsBranchesBranchIdCdhDataReceiveInterfacesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_: ModelsBranchesBranchIdCdhDataDataBusses,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataBussesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_: ModelsBranchesBranchIdCdhDataDataStorage,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataStorageBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_: ModelsBranchesBranchIdCdhDataDataModes,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_BLOCK_ID: ModelsBranchesBranchIdCdhDataDataModesBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_: ModelsBranchesBranchIdCdhDataModem,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_BLOCK_ID: ModelsBranchesBranchIdCdhDataModemBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_: ModelsBranchesBranchIdCdhDataAntenna,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_BLOCK_ID: ModelsBranchesBranchIdCdhDataAntennaBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_: ModelsBranchesBranchIdCdhDataLaserCommModule,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_BLOCK_ID: ModelsBranchesBranchIdCdhDataLaserCommModuleBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_: ModelsBranchesBranchIdPowerSolarArrays,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_BLOCK_ID: ModelsBranchesBranchIdPowerSolarArraysBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_: ModelsBranchesBranchIdPowerSolarArraysPanels,
@@ -302,7 +368,7 @@ path_to_api = PathToApi(
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesPacksBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_: ModelsBranchesBranchIdPowerBatteriesCells,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_BLOCK_ID: ModelsBranchesBranchIdPowerBatteriesCellsBlockId,
-        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_TOPOLOGY_BLOCK_ID: ModelsBranchesBranchIdPowerEpsTopologyBlockId,
+        PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_POWERPROCESSOR_BLOCK_ID: ModelsBranchesBranchIdPowerEpsPowerProcessorBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_: ModelsBranchesBranchIdPowerEpsBusRegulators,
         PathValues.MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_BLOCK_ID: ModelsBranchesBranchIdPowerEpsBusRegulatorsBlockId,
         PathValues.MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_: ModelsBranchesBranchIdThermalTempControllersHeaters,
