@@ -35,6 +35,28 @@ class PathValues(str, enum.Enum):
     MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_GROUNDTARGETS_BLOCK_ID = "/models/branches/{branchId}/cdh/conops/ground-targets/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_ = "/models/branches/{branchId}/cdh/conops/target-groups/"
     MODELS_BRANCHES_BRANCH_ID_CDH_CONOPS_TARGETGROUPS_BLOCK_ID = "/models/branches/{branchId}/cdh/conops/target-groups/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_ = "/models/branches/{branchId}/cdh/data/data-types/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATATYPES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/data-types/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_ = "/models/branches/{branchId}/cdh/data/internal-data-interfaces/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_INTERNALDATAINTERFACES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/internal-data-interfaces/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_ = "/models/branches/{branchId}/cdh/data/passive-transmit-interfaces/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_PASSIVETRANSMITINTERFACES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/passive-transmit-interfaces/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_ = "/models/branches/{branchId}/cdh/data/cooperative-transmit-interfaces/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_COOPERATIVETRANSMITINTERFACES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/cooperative-transmit-interfaces/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_ = "/models/branches/{branchId}/cdh/data/receive-interfaces/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_RECEIVEINTERFACES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/receive-interfaces/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_ = "/models/branches/{branchId}/cdh/data/data-busses/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATABUSSES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/data-busses/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_ = "/models/branches/{branchId}/cdh/data/data-storage/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATASTORAGE_BLOCK_ID = "/models/branches/{branchId}/cdh/data/data-storage/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_ = "/models/branches/{branchId}/cdh/data/data-modes/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_DATAMODES_BLOCK_ID = "/models/branches/{branchId}/cdh/data/data-modes/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_ = "/models/branches/{branchId}/cdh/data/modem/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_MODEM_BLOCK_ID = "/models/branches/{branchId}/cdh/data/modem/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_ = "/models/branches/{branchId}/cdh/data/antenna/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_ANTENNA_BLOCK_ID = "/models/branches/{branchId}/cdh/data/antenna/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_ = "/models/branches/{branchId}/cdh/data/laser-comm-module/"
+    MODELS_BRANCHES_BRANCH_ID_CDH_DATA_LASERCOMMMODULE_BLOCK_ID = "/models/branches/{branchId}/cdh/data/laser-comm-module/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_ = "/models/branches/{branchId}/power/solar-arrays/"
     MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_BLOCK_ID = "/models/branches/{branchId}/power/solar-arrays/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_POWER_SOLARARRAYS_PANELS_ = "/models/branches/{branchId}/power/solar-arrays/panels/"
@@ -46,7 +68,7 @@ class PathValues(str, enum.Enum):
     MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_PACKS_BLOCK_ID = "/models/branches/{branchId}/power/batteries/packs/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_ = "/models/branches/{branchId}/power/batteries/cells/"
     MODELS_BRANCHES_BRANCH_ID_POWER_BATTERIES_CELLS_BLOCK_ID = "/models/branches/{branchId}/power/batteries/cells/{blockId}"
-    MODELS_BRANCHES_BRANCH_ID_POWER_EPS_TOPOLOGY_BLOCK_ID = "/models/branches/{branchId}/power/eps/topology/{blockId}"
+    MODELS_BRANCHES_BRANCH_ID_POWER_EPS_POWERPROCESSOR_BLOCK_ID = "/models/branches/{branchId}/power/eps/power-processor/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_ = "/models/branches/{branchId}/power/eps/bus-regulators/"
     MODELS_BRANCHES_BRANCH_ID_POWER_EPS_BUSREGULATORS_BLOCK_ID = "/models/branches/{branchId}/power/eps/bus-regulators/{blockId}"
     MODELS_BRANCHES_BRANCH_ID_THERMAL_TEMPCONTROLLERS_HEATERS_ = "/models/branches/{branchId}/thermal/temp-controllers/heaters/"
